@@ -62,10 +62,9 @@ struct _GeditNotebookPrivate
 
 	GeditNotebookShowTabsModeType show_tabs_mode;
 
-	GtkBorder      padding;
+	GtkCssProvider *css;
 
 	guint          close_buttons_sensitive : 1;
-	guint          collapse_border : 1;
 };
 
 G_DEFINE_TYPE(GeditNotebook, gedit_notebook, GTK_TYPE_NOTEBOOK)
@@ -169,6 +168,12 @@ gedit_notebook_dispose (GObject *object)
 		notebook->priv->ui_settings = NULL;
 	}
 
+	if (notebook->priv->css != NULL)
+	{
+		g_object_unref (notebook->priv->css);
+		notebook->priv->css = NULL;
+	}
+
 	G_OBJECT_CLASS (gedit_notebook_parent_class)->dispose (object);
 }
 
@@ -651,52 +656,65 @@ gedit_notebook_get_close_buttons_sensitive (GeditNotebook *nb)
 	return nb->priv->close_buttons_sensitive;
 }
 
-void
-gedit_notebook_collapse_border (GeditNotebook *nb,
-                                gboolean       collapse)
+static void
+remove_right_padding (GeditNotebook *nb)
 {
 	GtkStyleContext *context;
-	GtkCssProvider *css;
-	GError *error = NULL;
+	GtkBorder padding;
 	gchar *modified_style;
-	const gchar notebook_style[] =
-		"* {\n"
-		"	padding-left: %d;\n"
-		"	padding-right: %d;\n"
+	GError *error = NULL;
+	const gchar style[] =
+		".notebook {\n"
+		"	padding: %d 0 %d %d;\n"
 		"}";
 
-	g_return_if_fail (GEDIT_IS_NOTEBOOK (nb));
-
-	nb->priv->collapse_border = collapse;
+	/* FIXME: find out a css like way to do this, right now padding-right/left
+         doesn't work */
 	context = gtk_widget_get_style_context (GTK_WIDGET (nb));
+	gtk_style_context_get_padding (context, gtk_style_context_get_state (context),
+	                               &padding);
 
-	if (collapse)
-	{
-		gtk_style_context_get_padding (context, 0, &nb->priv->padding);
-		modified_style = g_strdup_printf (notebook_style, 0, 0);
-	}
-	else
-	{
-		modified_style = g_strdup_printf (notebook_style,
-		                                  nb->priv->padding.left,
-		                                  nb->priv->padding.right);
-	}
+	modified_style = g_strdup_printf (style, padding.top, padding.bottom, padding.left);
 
 	/* make it as small as possible */
-	css = gtk_css_provider_new ();
-	if (gtk_css_provider_load_from_data (css, modified_style,
-	                                     -1, &error))
+	if (nb->priv->css == NULL)
 	{
-		gtk_style_context_add_provider (context, GTK_STYLE_PROVIDER (css),
-			                        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-		g_object_unref (css);
-		g_free (modified_style);
+		nb->priv->css = gtk_css_provider_new ();
+	}
+
+	if (gtk_css_provider_load_from_data (nb->priv->css, modified_style, -1, &error))
+	{
+		gtk_style_context_add_provider (context,
+		                                GTK_STYLE_PROVIDER (nb->priv->css),
+		                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	}
 	else
 	{
 		g_warning ("%s", error->message);
 		g_error_free (error);
-		g_free (modified_style);
+	}
+
+	g_free (modified_style);
+}
+
+void
+gedit_notebook_collapse_border (GeditNotebook *nb,
+                                gboolean       collapse)
+{
+	g_return_if_fail (GEDIT_IS_NOTEBOOK (nb));
+
+	if (collapse)
+	{
+		remove_right_padding (nb);
+	}
+	/* if we made some modification put it back to the default state */
+	else if (nb->priv->css != NULL)
+	{
+		GtkStyleContext *context;
+
+		context = gtk_widget_get_style_context (GTK_WIDGET (nb));
+		gtk_style_context_remove_provider (context,
+		                                   GTK_STYLE_PROVIDER (nb->priv->css));
 	}
 }
 
